MethodChannelDeviceSecurityGuard class

Cài đặt DeviceSecurityGuardPlatform bằng method channel.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
Method channel dùng để giao tiếp với nền tảng native.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

assessLocal(SecurityOptions options) Future<SecurityAssessment>
Chạy assessment native và chuẩn hóa payload thành SecurityAssessment.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited