DeviceSecurityGuardPlatform class abstract

Hợp đồng platform implementation của device_security_guard.

Inheritance
  • Object
  • PlatformInterface
  • DeviceSecurityGuardPlatform
Implementers

Constructors

DeviceSecurityGuardPlatform()
Khởi tạo platform interface.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

assessLocal(SecurityOptions options) Future<SecurityAssessment>
Chạy các detector cục bộ của nền tảng.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance DeviceSecurityGuardPlatform
Instance DeviceSecurityGuardPlatform đang được sử dụng.
getter/setter pair

Constants

androidSignals → const Set<SecuritySignal>
Toàn bộ tín hiệu bắt buộc trong payload Android.
iosSignals → const Set<SecuritySignal>
Toàn bộ tín hiệu bắt buộc trong payload iOS.