SecuritySignal enum
Dấu hiệu bảo mật được package kiểm tra.
Values
- debugger → const SecuritySignal
-
Trình gỡ lỗi đang gắn hoặc đang chờ kết nối.
- emulator → const SecuritySignal
-
Ứng dụng đang chạy trên emulator hoặc simulator.
- adbEnabled → const SecuritySignal
-
Android Debug Bridge đang được bật.
- hooking → const SecuritySignal
-
Có dấu hiệu framework hook hoặc thư viện chèn mã runtime.
- repackaging → const SecuritySignal
-
Danh tính ký của ứng dụng không khớp cấu hình mong đợi.
- root → const SecuritySignal
-
Có dấu hiệu thiết bị Android đã root.
- jailbreak → const SecuritySignal
-
Có dấu hiệu thiết bị iOS đã jailbreak.
- bootloaderUnlocked → const SecuritySignal
-
Có dấu hiệu bootloader Android đã mở khóa.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SecuritySignal> - A constant List of the values in this enum, in order of their declaration.